from setuptools import setup

setup(name='mmc_distributions',
      version='0.1',
      description='Probability distributions',
      packages=['mmc_distributions'],
      author = 'Michael McMahon',
      author_email = 'michael-mcmahon94@hotmail.com',
      zip_safe=False)
